![tests workflow status](https://github.com/hchau630/tdfl/actions/workflows/tests.yml/badge.svg)
[![codecov](https://codecov.io/gh/hchau630/tdfl/graph/badge.svg?token=OH3WD4MORQ)](https://codecov.io/gh/hchau630/tdfl)

# tdfl - Torch DataFrame Lite
DataFrame supporting PyTorch Tensor columns. It is "Lite" in the sense that only minimal features are implemented according to my own personal usage.

# Install
```
pip install tdfl
```